Learn R Programming

dcce (version 0.4.2)

.andrews_sup_wald_cv: Andrews (1993) sup-Wald critical values

Description

Lookup for asymptotic critical values of the sup-Wald statistic under symmetric trimming, taken from Andrews (1993, Econometrica 61(4), Table I, columns for the sup-LM / sup-Wald test). Values are tabulated for q (number of tested parameters) from 1 to 10 and trimming fractions pi_0 in the set (0.01, 0.05, 0.10, 0.15, 0.20, 0.25). For values of q above 10 the function linearly extrapolates in q at the nearest tabulated pi_0. For intermediate pi_0 values the function uses the nearest tabulated column.

Usage

.andrews_sup_wald_cv(q, pi0)

Value

A named numeric vector with elements cv10, cv05, cv01 for the 10\

Arguments

q

Integer: number of tested parameters.

pi0

Numeric in (0, 0.5): symmetric trimming fraction.