Learn R Programming

dcce (version 0.4.2)

.delta_method: Delta Method

Description

Computes standard errors for nonlinear transformations of parameters using the delta method: V(g(b)) = G' V(b) G where G = dg/db.

Usage

.delta_method(g, b, V, h = 1e-06)

Value

A list with estimate (transformed values) and vcov (delta-method variance).

Arguments

g

A function of the parameter vector returning the transformed values.

b

Numeric vector: parameter estimates.

V

Numeric matrix: variance-covariance of b.

h

Numeric: step size for numerical differentiation. Default 1e-6.