Learn R Programming

dcce (version 0.4.2)

hausman_test: Hausman-type Test: MG vs Pooled

Description

Tests the null that the pooled and MG estimators are both consistent (i.e. slopes are homogeneous and the pooled estimator is efficient) against the alternative that slopes are heterogeneous and only MG is consistent. The test statistic is $$H = (\hat\beta_{MG} - \hat\beta_{pool})' [V_{MG} - V_{pool}]^{-1} (\hat\beta_{MG} - \hat\beta_{pool}) \sim \chi^2_k.$$

Usage

hausman_test(object)

Value

An object of class dcce_hausman with the test statistic, degrees of freedom, and p-value.

Arguments

object

A dcce_fit object.