Learn R Programming

dcce (version 0.4.2)

predict.dcce_fit: Predict from a dcce_fit object

Description

Predict from a dcce_fit object

Usage

# S3 method for dcce_fit
predict(object, newdata = NULL, type = c("response", "xb"), ...)

Value

A numeric vector of predictions.

Arguments

object

A dcce_fit object.

newdata

Optional data.frame with new observations. When supplied, predictions are computed using the Mean Group coefficients on the structural regressors (CSAs are not applied because they depend on the full cross-section). When NULL, in-sample unit-level fitted values are returned.

type

Character: "response" (default) returns predicted y; "xb" is an alias for response (kept for compatibility with marginaleffects).

...

Ignored.