.absorb_resolve: Resolve absorb argument to a list of grouping vectors
Description
Resolve absorb argument to a list of grouping vectors
Usage
.absorb_resolve(absorb, panel)
Value
A named list of grouping factors (one per variable) or
NULL if no absorb requested.
Arguments
- absorb
Either NULL, a character vector of column names,
or a one-sided formula like ~ industry + year.
- panel
A panel data.frame.