Tests the null that the pooled and MG estimators are both consistent (i.e. slopes are homogeneous and the pooled estimator is efficient) against the alternative that slopes are heterogeneous and only MG is consistent. The test statistic is $$H = (\hat\beta_{MG} - \hat\beta_{pool})' [V_{MG} - V_{pool}]^{-1} (\hat\beta_{MG} - \hat\beta_{pool}) \sim \chi^2_k.$$
hausman_test(object)An object of class dcce_hausman with the test statistic,
degrees of freedom, and p-value.
A dcce_fit object.