Predict from a dcce_fit object
# S3 method for dcce_fit
predict(object, newdata = NULL, type = c("response", "xb"), ...)A numeric vector of predictions.
A dcce_fit object.
Optional data.frame with new observations. When supplied,
predictions are computed using the Mean Group coefficients on the
structural regressors (CSAs are not applied because they depend on the
full cross-section). When NULL, in-sample unit-level fitted
values are returned.
Character: "response" (default) returns predicted y;
"xb" is an alias for response (kept for compatibility with
marginaleffects).
Ignored.